@@ -22,7 +22,7 @@ class GamsPandasDatabase:
   Changes to retrieved series are written to the GAMS database on export.
   """
 
-  def __init__(self, database=None, workspace=None, auto_sort_index=True):
+  def __init__(self, database=None, workspace=None, auto_sort_index=True, sparse=True):
     if database is None:
       if workspace is None:
         workspace = gams.GamsWorkspace()
@@ -30,6 +30,7 @@ class GamsPandasDatabase:
     self.database = database
     self.gams2numpy = gams2numpy.Gams2Numpy(database.workspace.system_directory)
     self.auto_sort_index = auto_sort_index
+    self.sparse = sparse
     self.series = {}
 
   def __getattr__(self, item):
@@ -100,9 +101,11 @@ class GamsPandasDatabase:
     for identifier in args:
       setattr(builtins, identifier, self[identifier])
 
-  def get(self, *args):
+  def get(self, *args, sparse=None):
     """Retrieve any nymber of symbol names and return a list of their Pandas representations."""
-    return [self[i] for i in args]
+    if sparse is None:
+      sparse = self.sparse
+    return [self.getitem(i, sparse) for i in args]
 
   def add_parameter_from_dataframe(self, identifier, df, explanatory_text="", add_missing_domains=False,
                                    value_column_index=-1):
@@ -259,7 +262,7 @@ class GamsPandasDatabase:
       pass
     return t
 
-  def series_from_symbol(self, symbol, attributes, attribute):
+  def series_from_symbol(self, symbol, sparse, attributes, attribute):
     index_names = index_names_from_symbol(symbol)
     try:
       df = pd.DataFrame(
@@ -274,19 +277,32 @@ class GamsPandasDatabase:
     for i in index_names:
       df[i] = map_to_int_where_possible(df[i])
     df.set_index(index_names, inplace=True)
-    if len(df) == 0:
-      df.index = self.get_index([self[i] for i in index_names])[[]]  # Get the correct data types and size of index
-    series = df[attribute].astype(float)
+    if sparse:
+      if len(df) == 0:
+        df.index = self.get_index([self[i] for i in index_names])[[]]  # Get the correct data types and size of index
+      series = df[attribute].astype(float)
+    else:
+      assert all([i in self for i in index_names]), "Cannot get dense representation of series if sets are not included in database."
+      if len(index_names) > 1:
+        index = pd.MultiIndex.from_product([self[i] for i in index_names])
+      else:
+        index = self[index_names[0]]
+      index.names = index_names
+      series = pd.Series(0.0, index=index)
+      series = series + df[attribute]
     series.name = symbol.name
     return series
 
-  def series_from_variable(self, symbol, attr="level"):
-    return self.series_from_symbol(symbol, attributes=["level", "marginal", "lower", "upper", "scale"], attribute="level")
+  def series_from_variable(self, symbol, sparse):
+    return self.series_from_symbol(symbol, sparse, attributes=["level", "marginal", "lower", "upper", "scale"], attribute="level")
 
-  def series_from_parameter(self, symbol):
-    return self.series_from_symbol(symbol, attributes=["value"], attribute="value")
+  def series_from_parameter(self, symbol, sparse):
+    return self.series_from_symbol(symbol, sparse, attributes=["value"], attribute="value")
+
+  def getitem(self, item, sparse=None):
+    if sparse is None:
+      sparse = self.sparse
 
-  def __getitem__(self, item):
     if item not in self.series:
       symbol = self.symbols[item]
 
@@ -297,7 +313,7 @@ class GamsPandasDatabase:
         if symbol_is_scalar(symbol):
           self.series[item] = symbol.find_record().level if len(symbol) else None
         else:
-          self.series[item] = self.series_from_variable(symbol)
+          self.series[item] = self.series_from_variable(symbol, sparse)
           if self.auto_sort_index:
             self.series[item] = self.series[item].sort_index()
 
@@ -305,15 +321,17 @@ class GamsPandasDatabase:
         if symbol_is_scalar(symbol):
           self.series[item] = symbol.find_record().value if len(symbol) else None
         else:
-          self.series[item] = self.series_from_parameter(symbol)
+          self.series[item] = self.series_from_parameter(symbol, sparse)
           if self.auto_sort_index:
             self.series[item] = self.series[item].sort_index()
 
       elif isinstance(symbol, gams.GamsEquation):
         return symbol
-
     return self.series[item]
 
+  def __getitem__(self, item):
+    return self.getitem(item)
+
   def __setitem__(self, name, value):
     if name in self.symbols:
       if not is_iterable(value) and is_iterable(self[name]):  # If assigning a scalar to all records in a series
