@@ -285,4 +285,12 @@ def test_import_export_empty():
   db = dt.Gdx("test_export.gdx")
 
   assert all(db.p == 1)
-  assert all(db.v == 1)
\ No newline at end of file
+  assert all(db.v == 1)
+
+def test_get_sparse():
+  db = dt.Gdx("test.gdx")
+  dense = dt.Gdx("test.gdx", sparse=False)
+  assert len(dense["qY"]) > len(db["qY"])
+  assert len(dense["qY"]) == len(pd.MultiIndex.from_product(db.get("s_", "t")))
+  assert len(dense["pBolig"]) == len(db["t"])
+
